@@ -17,17 +17,18 @@ package Dist::Zilla::Plugin::MakeMaker::Custom;
 # ABSTRACT: Allow a dist to have a custom Makefile.PL
 #---------------------------------------------------------------------
 
-our $VERSION = '4.24';
-# This file is part of Dist-Zilla-Plugins-CJM 4.25 (November 8, 2014)
+our $VERSION = '4.26';
+# This file is part of Dist-Zilla-Plugins-CJM 4.26 (December 13, 2014)
 
 
 use Moose;
-use Moose::Autobox;
 use Dist::Zilla::Plugin::MakeMaker 4.300009; # improved subclassing
 extends 'Dist::Zilla::Plugin::MakeMaker';
 with qw(Dist::Zilla::Role::FilePruner
         Dist::Zilla::Role::HashDumper);
 
+use List::Util ();
+
 # We're trying to make the template executable before it's filled in,
 # so we want delimiters that look like comments:
 has '+delim' => (
@@ -118,7 +119,8 @@ around setup_installer => sub {
   my $orig = shift;
   my $self = shift;
 
-  my $file = $self->zilla->files->grep(sub { $_->name eq 'Makefile.PL' })->head
+  my $file = List::Util::first { $_->name eq 'Makefile.PL' }
+             @{ $self->zilla->files }
       or $self->log_fatal("No Makefile.PL found in dist");
 
   my $write_makefile_args = $self->_mmc_write_makefile_args;
@@ -180,9 +182,9 @@ Dist::Zilla::Plugin::MakeMaker::Custom - Allow a dist to have a custom Makefile.
 
 =head1 VERSION
 
-This document describes version 4.24 of
-Dist::Zilla::Plugin::MakeMaker::Custom, released November 8, 2014
-as part of Dist-Zilla-Plugins-CJM version 4.25.
+This document describes version 4.26 of
+Dist::Zilla::Plugin::MakeMaker::Custom, released December 13, 2014
+as part of Dist-Zilla-Plugins-CJM version 4.26.
 
 =head1 SYNOPSIS
 
